==> react-gui-common-1.3.262.tgz: package/src/baseContainers/BaseListContainer.js <==
/* eslint-disable import/no-extraneous-dependencies */
/* eslint-disable react/jsx-handler-names */
import React from 'react';
// import { DataTable } from 'primereact/datatable';
import { Column } from 'primereact/column';
import { Card } from 'primereact/card';
import PropTypes from 'prop-types';
import CustomMessages from '../components/CustomMessages';
import BaseContainer from './BaseContainer';
import ActionButton from '../components/ActionButton';
import ActionLink from '../components/ActionLink';
import DivContainer from '../components/DivContainer';
import BlockUi from '../components/waitPanel/BlockUi';
import Dropdown from '../components/base/Dropdown';
import CustomDataTable from '../components/base/CustomDataTable';

class BaseListContainer extends BaseContainer {
	constructor(props, service) {
		super(props);
		this.service = service;
		this.actionTemplate = this.actionTemplate.bind(this);
		this.handleGoToDetail = this.handleGoToDetail.bind(this);
		this.handleGoToDetails = this.handleGoToDetails.bind(this);
		this.handleGoToNew = this.handleGoToNew.bind(this);
		this.handleSort = this.handleSort.bind(this);
		this.handlePage = this.handlePage.bind(this);
		this.readCriteriaFromCookie = this.readCriteriaFromCookie.bind(this);
		this.readMessage = this.readMessage.bind(this);
		this.refreshTable = this.refreshTable.bind(this);
		this.renderDataTable = this.renderDataTable.bind(this);
		this.renderCriteria = this.renderCriteria.bind(this);
		this.renderHeader = this.renderHeader.bind(this);
		this.prepareColumns = this.prepareColumns.bind(this);
		this.getList = this.getList.bind(this);
		this.renderView = this.renderView.bind(this);
		this.getCleanSearchCriteria = this.getCleanSearchCriteria.bind(this);
		this.getCleanSearchCriteriaPrototype = this.getCleanSearchCriteriaPrototype.bind(this);
		this.updateSearchCriteria = this.updateSearchCriteria.bind(this);
		this.updateSearchCriteriaPrototype = this.updateSearchCriteriaPrototype.bind(this);
		this.onAfterGetList = this.onAfterGetList.bind(this);
		this.handleChangeLimitObj = this.handleChangeLimitObj.bind(this);
		this.handleClearSearchCriteria = this.handleClearSearchCriteria.bind(this);
		this.defaultLoading = true;
		if (service !== undefined && service !== null) {
			this.service.setUiMethods(this.blockUi, this.unblockUi);
		}
	}

	componentDidMount() {
		super.componentDidMount();
		this.initializeFromBackend();
		if (this.defaultLoading) {
			this.readCriteriaFromCookie();
		}
		this.readMessage();
		// eslint-disable-next-line no-undef
		// $('div.p-datatable div.p-paginator-top input').attr('aria-label', 'Liczba pozycji na stronie');
	}

	readCriteriaFromCookie() {
		const criteria =
			this.readCookie(this.getCriteriaName()) !== undefined &&
			this.readCookie(this.getCriteriaName()) != null
				? this.updateSearchCriteriaPrototype(JSON.parse(this.readCookie(this.getCriteriaName())))
				: this.getCleanSearchCriteriaPrototype();
		this.removeCookie(this.getCriteriaName());
		if (this._isMounted) {
			this.setState(
				{
					loading: true,
					criteria,
					first: criteria.page * criteria.limit,
				},
				() => {
					this.refreshTable();
				}
			);
		}
	}

	refreshTable() {
		this.getList();
	}

	onAfterGetList() {}

	getList() {
		const { criteria } = this.state;
		this.service
			.getList(criteria)
			.then(data => {
				if (this._isMounted) {
					this.setState(
						{
							list: data.content,
							loading: false,
							size: data.totalElements,
						},
						() => this.onAfterGetList()
					);
				}
			})
			.catch(err => {
				if (this._isMounted) {
					this.setState(
						{
							list: [],
							loading: false,
							size: 0,
						},
						() => {
							if (this.messages !== undefined) {
								this.messages.show({
									severity: 'error',
									life: 10000,
									summary: 'Błąd',
									detail: 'Wystąpił błąd systemu. Nie udało się pobrać listy.',
								});
							} else {
								console.log('getList this.messages === undefined', err);
							}
						}
					);
				}
			});
	}

	getCleanSearchCriteria() {
		return {
			page: 0,
			limit: 10,
			limitObj: { value: 10 },
			sortField: 'id',
			sortDirection: 'ASC',
		};
	}

	getCleanSearchCriteriaPrototype() {
		const criteria = this.getCleanSearchCriteria();
		criteria.limitObj = { value: criteria.limit };
		return criteria;
	}

	updateSearchCriteria(criteria) {
		return {
			page: criteria.page,
			limit: criteria.limit,
			limitObj: { value: criteria.limit },
			sortField: criteria.sortField,
			sortDirection: criteria.sortDirection,
		};
	}

	updateSearchCriteriaPrototype(criteria) {
		criteria = this.updateSearchCriteria(criteria);
		criteria.limitObj = { value: criteria.limit };
		return criteria;
	}

	getCriteriaName() {
		return 'list-sc';
	}

	initializeFromBackend() {}

	handleSort(event) {
		if (this._isMounted) {
			this.setState(
				prevState => ({
					loading: true,
					criteria: {
						...prevState.criteria,
						sortField: event.sortField,
						sortDirection: event.sortOrder > 0 ? 'ASC' : 'DESC',
					},
				}),
				() => this.refreshTable()
			);
		}
	}

	handlePage(event) {
		if (this._isMounted) {
			this.setState(
				prevState => ({
					loading: true,
					first: event.first,
					criteria: {
						...prevState.criteria,
						page: event.page,
						limit: event.rows,
						limitObj: { value: event.rows },
					},
				}),
				() => this.refreshTable()
			);
		}
	}

	handleValidForm() {
		this.setState(
			prevState => ({
				blocking: false,
				loading: true,
				first: 0,
				criteria: {
					...prevState.criteria,
					page: 0,
				},
			}),
			() => this.refreshTable()
		);
	}

	getContainerListName() {
		return 'list-container';
	}

	readMessage() {
		const messageFromStorage = this.readCookie(this.getContainerListName());
		if (messageFromStorage !== undefined && messageFromStorage != null) {
			const message = JSON.parse(messageFromStorage);
			this.removeCookie(this.getContainerListName());
			if (
				message.severity !== undefined &&
				message.severity != null &&
				message.summary !== undefined &&
				message.summary != null &&
				message.detail !== undefined &&
				message.detail != null
			) {
				this.messages.show({
					severity: message.severity,
					summary: message.summary,
					detail: message.detail,
				});
			}
		}
	}

	handleGoToDetail(href, e) {
		e.preventDefault();
		this.blockUi();
		const { criteria } = this.state;
		this.saveCookie(this.getCriteriaName(), JSON.stringify(criteria));
		window.location.href = href;
	}

	handleGoToDetails(e) {
		e.preventDefault();
		this.blockUi();
		const { detailUrl } = this.props;
		const { criteria } = this.state;
		this.saveCookie(this.getCriteriaName(), JSON.stringify(criteria));
		window.location.href = detailUrl;
	}

	handleGoToNew(e) {
		e.preventDefault();
		this.blockUi();
		const { newUrl } = this.props;
		const { criteria } = this.state;
		this.saveCookie(this.getCriteriaName(), JSON.stringify(criteria));
		window.location.href = newUrl;
	}

	actionTemplate(rowData) {
		const { detailUrl } = this.props;
		const href = `${detailUrl}?id=${rowData.id}`;
		return (
			<ActionLink
				label={'Szczegóły'}
				handleClick={this.handleGoToDetail.bind(this, href)}
				variant="accent"
				className="p-link hover-underline"
				key={'view-button'}
				iconSize="xs"
				iconName="mdi-arrow-right"
				iconColor="accent"
			/>
		);
	}

	addButton() {
		const { newUrl } = this.props;
		return (
			<ActionButton
				label={'Dodaj'}
				handleClick={this.handleGoToDetail.bind(this, newUrl)}
				key={'add-button'}
				rendered={!this.isInterpersonatedUser()}
			/>
		);
	}

	handleChangeSc(event, optionValue, onAfterSetState) {
		const varName = event.target.name;
		let varValue = event.checked !== undefined ? event.checked : event.target.value;
		if (varValue === '' || varValue === null) {
			varValue = undefined;
		}
		if (optionValue !== null && optionValue !== undefined) {
			let varValueEnum = undefined;
			if (varValue) {
				varValueEnum = varValue[optionValue];
			}
			if (this._isMounted) {
				this.setState(
					prevState => ({
						criteria: {
							...prevState.criteria,
							[`${varName}Obj`]: varValue,
							[varName]: varValueEnum,
						},
					}),
					onAfterSetState ? onAfterSetState : null
				);
			}
		} else {
			if (this._isMounted) {
				this.setState(
					prevState => ({
						criteria: {
							...prevState.criteria,
							[varName]: varValue,
						},
					}),
					onAfterSetState ? onAfterSetState : null
				);
			}
		}
	}
	handleChangeLimitObj(v) {
		this.setState(
			prevState => ({
				first: 0,
				criteria: {
					...prevState.criteria,
					page: 0,
				},
			}),
			() => this.refreshTable()
		);
	}
	renderDataTable(columns) {
		const { criteria, first, list, loading, size } = this.state;
		const dynamicColumns = columns.map(col => {
			return (
				<Column
					key={col.key ? col.key : col.field}
					field={col.field}
					header={col.header}
					body={col.body}
					className={col.className}
					sortable={col.sortable}
					style={col.width !== undefined ? { width: col.width } : null}
				/>
			);
		});
		const rowsPerPageOptions = [5, 10, 20, 50, 100];
		const rowsPerPageOptionsObj = [
			{ value: 5 },
			{ value: 10 },
			{ value: 20 },
			{ value: 50 },
			{ value: 100 },
		];
		return (
			<DivContainer colClass="row">
				<div className="p-datatable p-component p-datatable-responsive ade-table">
					<div className="p-paginator p-component p-unselectable-text p-paginator-top">
						<label id={'limit-label-id'} className="easy_label" htmlFor={'limit-input'}>
							Pokaż na stronie
						</label>
						<Dropdown
							ariaLabel={'Pokaż na stronie'}
							key={'limit'}
							id={'limit'}
							inputId={'limit-input'}
							name={'limit'}
							style={{ width: '100%' }}
							value={this.state.criteria.limitObj}
							options={rowsPerPageOptionsObj}
							optionLabel={'value'}
							dataKey={'value'}
							onChange={e => this.handleChangeSc(e, 'value', () => this.handleChangeLimitObj(e))}
							filter={false}
							showClear={false}
						/>
					</div>
				</div>
				<CustomDataTable
					key="data-table"
					emptyMessage="Brak rekordów do wyświetlenia"
					className="ade-table"
					responsive
					value={list}
					paginator
					rows={criteria.limit}
					totalRecords={size}
					lazy
					first={first}
					onPage={this.handlePage}
					rowsPerPageOptions={rowsPerPageOptions}
					onSort={this.handleSort}
					sortField={criteria.sortField}
					sortOrder={criteria.sortDirection === 'ASC' ? 1 : -1}
					loading={loading}
					paginatorPosition="bottom"
					currentPageReportTemplate={
						size !== 0
							? `Pozycje od ${first + 1} do ${
									first + criteria.limit > size ? size : first + criteria.limit
							  } z ${size} łącznie`
							: '0 pozycji'
					}
					paginatorTemplate="CurrentPageReport FirstPageLink PrevPageLink PageLinks NextPageLink LastPageLink"
					pageLinkSize={5}
				>
					{dynamicColumns}
				</CustomDataTable>
			</DivContainer>
		);
	}

	prepareColumns() {
		return [];
	}

	renderCriteria() {
		return <DivContainer colClass="row" />;
	}

	renderView() {
		return (
			<DivContainer colClass="">
				<CustomMessages ref={el => (this.messages = el)} />
				<BlockUi
					tag="div"
					blocking={this.state.blocking || this.state.loading}
					loader={this.loader}
				>
					<Card header={this.renderHeader()}>
						<DivContainer colClass="row">
							<form
								className="form-search-criteria"
								onSubmit={e => {
									this.handleFormSubmit(e);
								}}
								onKeyDown={e => {
									if (e.key === 'Enter') {
										e.preventDefault();
										this.handleFormSubmit();
									}
								}}
								//avoid setting red border just after the page has loaded (red border because of undefined required value in FF)
								noValidate
							>
								{/* <DivContainer colClass="col-12"> */}
								<DivContainer colClass="row">
									<DivContainer colClass="col-criteria">{this.renderCriteria()}</DivContainer>
									<DivContainer colClass="col-filter">
										<div class="row" style={{ float: 'right', display: 'inline' }}>
											<ActionButton
												className="search-button"
												label="Filtruj"
												handleClick={this.handleFormSubmit}
											/>
											<ActionButton
												className="search-button"
												label="Wyczyść"
												handleClick={this.handleClearSearchCriteria}
											/>
										</div>
									</DivContainer>
								</DivContainer>
								{/* </DivContainer> */}
							</form>
						</DivContainer>
						{this.renderDataTable(this.prepareColumns())}
					</Card>
				</BlockUi>
			</DivContainer>
		);
	}
	handleClearSearchCriteria(event) {
		const criteria = this.getCleanSearchCriteria();
		if (this._isMounted) {
			this.setState(
				{
					loading: true,
					criteria: criteria,
					first: criteria.firstResult,
				},
				() => {
					this.refreshTable();
				}
			);
		}
	}
}

BaseListContainer.defaultProps = {
	roles: '',
};

BaseListContainer.propTypes = {
	detailUrl: PropTypes.string,
	newUrl: PropTypes.string,
	roles: PropTypes.string,
};

export default BaseListContainer;

==> react-gui-common-1.3.263.tgz: package/src/baseContainers/BaseListContainer.js <==
/* eslint-disable import/no-extraneous-dependencies */
/* eslint-disable react/jsx-handler-names */
import React from 'react';
// import { DataTable } from 'primereact/datatable';
import { Column } from 'primereact/column';
import { Card } from 'primereact/card';
import PropTypes from 'prop-types';
import CustomMessages from '../components/CustomMessages';
import BaseContainer from './BaseContainer';
import ActionButton from '../components/ActionButton';
import ActionLink from '../components/ActionLink';
import DivContainer from '../components/DivContainer';
import BlockUi from '../components/waitPanel/BlockUi';
import Dropdown from '../components/base/Dropdown';
import CustomDataTable from '../components/base/CustomDataTable';

class BaseListContainer extends BaseContainer {
	constructor(props, service) {
		super(props);
		this.service = service;
		this.actionTemplate = this.actionTemplate.bind(this);
		this.handleGoToDetail = this.handleGoToDetail.bind(this);
		this.handleGoToDetails = this.handleGoToDetails.bind(this);
		this.handleGoToNew = this.handleGoToNew.bind(this);
		this.handleSort = this.handleSort.bind(this);
		this.handlePage = this.handlePage.bind(this);
		this.readCriteriaFromCookie = this.readCriteriaFromCookie.bind(this);
		this.readMessage = this.readMessage.bind(this);
		this.refreshTable = this.refreshTable.bind(this);
		this.renderDataTable = this.renderDataTable.bind(this);
		this.renderCriteria = this.renderCriteria.bind(this);
		this.renderHeader = this.renderHeader.bind(this);
		this.prepareColumns = this.prepareColumns.bind(this);
		this.getList = this.getList.bind(this);
		this.renderView = this.renderView.bind(this);
		this.getCleanSearchCriteria = this.getCleanSearchCriteria.bind(this);
		this.getCleanSearchCriteriaPrototype = this.getCleanSearchCriteriaPrototype.bind(this);
		this.updateSearchCriteria = this.updateSearchCriteria.bind(this);
		this.updateSearchCriteriaPrototype = this.updateSearchCriteriaPrototype.bind(this);
		this.onAfterGetList = this.onAfterGetList.bind(this);
		this.handleChangeLimitObj = this.handleChangeLimitObj.bind(this);
		this.handleClearSearchCriteria = this.handleClearSearchCriteria.bind(this);
		this.defaultLoading = true;
		if (service !== undefined && service !== null) {
			this.service.setUiMethods(this.blockUi, this.unblockUi);
		}
	}

	componentDidMount() {
		super.componentDidMount();
		this.initializeFromBackend();
		if (this.defaultLoading) {
			this.readCriteriaFromCookie();
		}
		this.readMessage();
		// eslint-disable-next-line no-undef
		// $('div.p-datatable div.p-paginator-top input').attr('aria-label', 'Liczba pozycji na stronie');
	}

	readCriteriaFromCookie() {
		const criteria =
			this.readCookie(this.getCriteriaName()) !== undefined &&
			this.readCookie(this.getCriteriaName()) != null
				? this.updateSearchCriteriaPrototype(JSON.parse(this.readCookie(this.getCriteriaName())))
				: this.getCleanSearchCriteriaPrototype();
		this.removeCookie(this.getCriteriaName());
		if (this._isMounted) {
			this.setState(
				{
					loading: true,
					criteria,
					first: criteria.page * criteria.limit,
				},
				() => {
					this.refreshTable();
				}
			);
		}
	}

	refreshTable() {
		this.getList();
	}

	onAfterGetList() {}

	getList() {
		const { criteria } = this.state;
		this.service
			.getList(criteria)
			.then(data => {
				if (this._isMounted) {
					this.setState(
						{
							list: data.content,
							loading: false,
							size: data.totalElements,
						},
						() => this.onAfterGetList()
					);
				}
			})
			.catch(err => {
				if (this._isMounted) {
					this.setState(
						{
							list: [],
							loading: false,
							size: 0,
						},
						() => {
							if (this.messages !== undefined) {
								this.messages.show({
									severity: 'error',
									life: 10000,
									summary: 'Błąd',
									detail: 'Wystąpił błąd systemu. Nie udało się pobrać listy.',
								});
							} else {
								console.log('getList this.messages === undefined', err);
							}
						}
					);
				}
			});
	}

	getCleanSearchCriteria() {
		return {
			page: 0,
			limit: 10,
			limitObj: { value: 10 },
			sortField: 'id',
			sortDirection: 'ASC',
		};
	}

	getCleanSearchCriteriaPrototype() {
		const criteria = this.getCleanSearchCriteria();
		criteria.limitObj = { value: criteria.limit };
		return criteria;
	}

	updateSearchCriteria(criteria) {
		return {
			page: criteria.page,
			limit: criteria.limit,
			limitObj: { value: criteria.limit },
			sortField: criteria.sortField,
			sortDirection: criteria.sortDirection,
		};
	}

	updateSearchCriteriaPrototype(criteria) {
		criteria = this.updateSearchCriteria(criteria);
		criteria.limitObj = { value: criteria.limit };
		return criteria;
	}

	getCriteriaName() {
		return 'list-sc';
	}

	initializeFromBackend() {}

	handleSort(event) {
		if (this._isMounted) {
			this.setState(
				prevState => ({
					loading: true,
					criteria: {
						...prevState.criteria,
						sortField: event.sortField,
						sortDirection: event.sortOrder > 0 ? 'ASC' : 'DESC',
					},
				}),
				() => this.refreshTable()
			);
		}
	}

	handlePage(event) {
		if (this._isMounted) {
			this.setState(
				prevState => ({
					loading: true,
					first: event.first,
					criteria: {
						...prevState.criteria,
						page: event.page,
						limit: event.rows,
						limitObj: { value: event.rows },
					},
				}),
				() => this.refreshTable()
			);
		}
	}

	handleValidForm() {
		this.setState(
			prevState => ({
				blocking: false,
				loading: true,
				first: 0,
				criteria: {
					...prevState.criteria,
					page: 0,
				},
			}),
			() => this.refreshTable()
		);
	}

	getContainerListName() {
		return 'list-container';
	}

	readMessage() {
		const messageFromStorage = this.readCookie(this.getContainerListName());
		if (messageFromStorage !== undefined && messageFromStorage != null) {
			const message = JSON.parse(messageFromStorage);
			this.removeCookie(this.getContainerListName());
			if (
				message.severity !== undefined &&
				message.severity != null &&
				message.summary !== undefined &&
				message.summary != null &&
				message.detail !== undefined &&
				message.detail != null
			) {
				this.messages.show({
					severity: message.severity,
					summary: message.summary,
					detail: message.detail,
				});
			}
		}
	}

	handleGoToDetail(href, e) {
		e.preventDefault();
		this.blockUi();
		const { criteria } = this.state;
		this.saveCookie(this.getCriteriaName(), JSON.stringify(criteria));
		window.location.href = href;
	}

	handleGoToDetails(e) {
		e.preventDefault();
		this.blockUi();
		const { detailUrl } = this.props;
		const { criteria } = this.state;
		this.saveCookie(this.getCriteriaName(), JSON.stringify(criteria));
		window.location.href = detailUrl;
	}

	handleGoToNew(e) {
		e.preventDefault();
		this.blockUi();
		const { newUrl } = this.props;
		const { criteria } = this.state;
		this.saveCookie(this.getCriteriaName(), JSON.stringify(criteria));
		window.location.href = newUrl;
	}

	actionTemplate(rowData) {
		const { detailUrl } = this.props;
		const href = `${detailUrl}?id=${rowData.id}`;
		return (
			<ActionLink
				label={'Szczegóły'}
				handleClick={this.handleGoToDetail.bind(this, href)}
				variant="accent"
				className="p-link hover-underline"
				key={'view-button'}
				iconSize="xs"
				iconName="mdi-arrow-right"
				iconColor="accent"
			/>
		);
	}

	addButton() {
		const { newUrl } = this.props;
		return (
			<ActionButton
				label={'Dodaj'}
				handleClick={this.handleGoToDetail.bind(this, newUrl)}
				key={'add-button'}
				rendered={!this.isInterpersonatedUser()}
			/>
		);
	}

	handleChangeSc(event, optionValue, onAfterSetState) {
		const varName = event.target.name;
		let varValue = event.checked !== undefined ? event.checked : event.target.value;
		if (varValue === '' || varValue === null) {
			varValue = undefined;
		}
		if (optionValue !== null && optionValue !== undefined) {
			let varValueEnum = undefined;
			if (varValue) {
				varValueEnum = varValue[optionValue];
			}
			if (this._isMounted) {
				this.setState(
					prevState => ({
						criteria: {
							...prevState.criteria,
							[`${varName}Obj`]: varValue,
							[varName]: varValueEnum,
						},
					}),
					onAfterSetState ? onAfterSetState : null
				);
			}
		} else {
			if (this._isMounted) {
				this.setState(
					prevState => ({
						criteria: {
							...prevState.criteria,
							[varName]: varValue,
						},
					}),
					onAfterSetState ? onAfterSetState : null
				);
			}
		}
	}
	handleChangeLimitObj(v) {
		this.setState(
			prevState => ({
				first: 0,
				criteria: {
					...prevState.criteria,
					page: 0,
				},
			}),
			() => this.refreshTable()
		);
	}
	renderDataTable(columns) {
		const { criteria, first, list, loading, size } = this.state;
		const dynamicColumns = columns.map(col => {
			return (
				<Column
					key={col.key ? col.key : col.field}
					field={col.field}
					header={col.header}
					body={col.body}
					className={col.className}
					sortable={col.sortable}
					style={col.width !== undefined ? { width: col.width } : null}
				/>
			);
		});
		const rowsPerPageOptions = [5, 10, 20, 50, 100];
		const rowsPerPageOptionsObj = [
			{ value: 5 },
			{ value: 10 },
			{ value: 20 },
			{ value: 50 },
			{ value: 100 },
		];
		return (
			<DivContainer colClass="row">
				<div className="p-datatable p-component p-datatable-responsive ade-table">
					<div className="p-paginator p-component p-unselectable-text p-paginator-top">
						<label id={'limit-label-id'} className="easy_label" htmlFor={'limit-input'}>
							Pokaż na stronie
						</label>
						<Dropdown
							ariaLabel={'Pokaż na stronie'}
							key={'limit'}
							id={'limit'}
							inputId={'limit-input'}
							name={'limit'}
							style={{ width: '100%' }}
							value={this.state.criteria.limitObj}
							options={rowsPerPageOptionsObj}
							optionLabel={'value'}
							dataKey={'value'}
							onChange={e => this.handleChangeSc(e, 'value', () => this.handleChangeLimitObj(e))}
							filter={false}
							showClear={false}
						/>
					</div>
				</div>
				<CustomDataTable
					key="data-table"
					emptyMessage="Brak rekordów do wyświetlenia"
					className="ade-table"
					responsive
					value={list}
					paginator
					rows={criteria.limit}
					totalRecords={size}
					lazy
					first={first}
					onPage={this.handlePage}
					rowsPerPageOptions={rowsPerPageOptions}
					onSort={this.handleSort}
					sortField={criteria.sortField}
					sortOrder={criteria.sortDirection === 'ASC' ? 1 : -1}
					loading={loading}
					paginatorPosition="bottom"
					currentPageReportTemplate={
						size !== 0
							? `Pozycje od ${first + 1} do ${
									first + criteria.limit > size ? size : first + criteria.limit
							  } z ${size} łącznie`
							: '0 pozycji'
					}
					paginatorTemplate="CurrentPageReport FirstPageLink PrevPageLink PageLinks NextPageLink LastPageLink"
					pageLinkSize={5}
				>
					{dynamicColumns}
				</CustomDataTable>
			</DivContainer>
		);
	}

	prepareColumns() {
		return [];
	}

	renderCriteria() {
		return <DivContainer colClass="row" />;
	}

	renderView() {
		return (
			<DivContainer colClass="">
				<CustomMessages ref={el => (this.messages = el)} />
				<BlockUi
					tag="div"
					blocking={this.state.blocking || this.state.loading}
					loader={this.loader}
				>
					<Card header={this.renderHeader()}>
						<DivContainer colClass="row">
							<form
								className="form-search-criteria"
								onSubmit={e => {
									this.handleFormSubmit(e);
								}}
								onKeyDown={e => {
									if (e.key === 'Enter') {
										e.preventDefault();
										this.handleFormSubmit();
									}
								}}
								//avoid setting red border just after the page has loaded (red border because of undefined required value in FF)
								noValidate
							>
								<DivContainer colClass="col-12">
								<DivContainer colClass="row">
									<DivContainer colClass="col-criteria">{this.renderCriteria()}</DivContainer>
									<DivContainer colClass="col-filter">
										<div class="float-bottom float-right">
										<div class="row" style={{ display: 'inline' }}>
											<ActionButton
												className="search-button"
												label="Filtruj"
												handleClick={this.handleFormSubmit}
											/>
											<ActionButton
												className="search-button"
												label="Wyczyść"
												handleClick={this.handleClearSearchCriteria}
											/>
											</div>
										</div>
									</DivContainer>
								</DivContainer>
								</DivContainer>
							</form>
						</DivContainer>
						{this.renderDataTable(this.prepareColumns())}
					</Card>
				</BlockUi>
			</DivContainer>
		);
	}
	handleClearSearchCriteria(event) {
		const criteria = this.getCleanSearchCriteria();
		if (this._isMounted) {
			this.setState(
				{
					loading: true,
					criteria: criteria,
					first: criteria.firstResult,
				},
				() => {
					this.refreshTable();
				}
			);
		}
	}
}

BaseListContainer.defaultProps = {
	roles: '',
};

BaseListContainer.propTypes = {
	detailUrl: PropTypes.string,
	newUrl: PropTypes.string,
	roles: PropTypes.string,
};

export default BaseListContainer;
